==> tencentcloud-sdk-nodejs-4.0.181.tgz: package/test/mrs.v20200910.test.js <==

const expect = require("chai").expect
const tencentcloud = require("../../tencentcloud-sdk-nodejs")
const client = new tencentcloud.mrs.v20200910.Client({
  credential: {
    secretId: process.env.secretId,
    secretKey: process.env.secretKey,
  },
  region: "ap-shanghai",
  profile: {
    signMethod: "TC3-HMAC-SHA256",
    httpProfile: {
      reqMethod: "POST",
      reqTimeout: 30,
      endpoint: "cvm.ap-shanghai.tencentcloudapi.com",
    },
  },
})
describe("mrs.v20200910.test.js", function () {

it("mrs.v20200910.ImageToClass", async function () {
    try {
       const data = await client.ImageToClass({})
       expect(data).to.be.ok
    } catch(error) {
      expect(error.requestId).to.be.ok
      expect(error.code).to.be.ok
    }
})

it("mrs.v20200910.TextToObject", async function () {
    try {
       const data = await client.TextToObject({})
       expect(data).to.be.ok
    } catch(error) {
      expect(error.requestId).to.be.ok
      expect(error.code).to.be.ok
    }
})

it("mrs.v20200910.ReportTextStructured", async function () {
    try {
       const data = await client.ReportTextStructured({})
       expect(data).to.be.ok
    } catch(error) {
      expect(error.requestId).to.be.ok
      expect(error.code).to.be.ok
    }
})

it("mrs.v20200910.ImageToObject", async function () {
    try {
       const data = await client.ImageToObject({})
       expect(data).to.be.ok
    } catch(error) {
      expect(error.requestId).to.be.ok
      expect(error.code).to.be.ok
    }
})

it("mrs.v20200910.ReportImageStructured", async function () {
    try {
       const data = await client.ReportImageStructured({})
       expect(data).to.be.ok
    } catch(error) {
      expect(error.requestId).to.be.ok
      expect(error.code).to.be.ok
    }
})

it("mrs.v20200910.TextToClass", async function () {
    try {
       const data = await client.TextToClass({})
       expect(data).to.be.ok
    } catch(error) {
      expect(error.requestId).to.be.ok
      expect(error.code).to.be.ok
    }
})

})

==> tencentcloud-sdk-nodejs-4.0.716.tgz: package/test/mrs.v20200910.test.js <==

const expect = require("chai").expect
const tencentcloud = require("../../tencentcloud-sdk-nodejs")
const client = new tencentcloud.mrs.v20200910.Client({
  credential: {
    secretId: process.env.secretId,
    secretKey: process.env.secretKey,
  },
  region: "ap-shanghai",
  profile: {
    signMethod: "TC3-HMAC-SHA256",
    httpProfile: {
      reqMethod: "POST",
      reqTimeout: 30,
      endpoint: "cvm.ap-shanghai.tencentcloudapi.com",
    },
  },
})
describe("mrs.v20200910.test.js", function () {

it("mrs.v20200910.ImageToClass", async function () {
    try {
       const data = await client.ImageToClass({})
       expect(data).to.be.ok
    } catch(error) {
      expect(error.requestId).to.be.ok
      expect(error.code).to.be.ok
    }
})

it("mrs.v20200910.TurnPDFToObject", async function () {
    try {
       const data = await client.TurnPDFToObject({})
       expect(data).to.be.ok
    } catch(error) {
      expect(error.requestId).to.be.ok
      expect(error.code).to.be.ok
    }
})

it("mrs.v20200910.ImageToObject", async function () {
    try {
       const data = await client.ImageToObject({})
       expect(data).to.be.ok
    } catch(error) {
      expect(error.requestId).to.be.ok
      expect(error.code).to.be.ok
    }
})

it("mrs.v20200910.TextToClass", async function () {
    try {
       const data = await client.TextToClass({})
       expect(data).to.be.ok
    } catch(error) {
      expect(error.requestId).to.be.ok
      expect(error.code).to.be.ok
    }
})

it("mrs.v20200910.TextToObject", async function () {
    try {
       const data = await client.TextToObject({})
       expect(data).to.be.ok
    } catch(error) {
      expect(error.requestId).to.be.ok
      expect(error.code).to.be.ok
    }
})

})
